@@ -777,7 +777,14 @@ def test_test_cli(mocker, tuxsuite_config):
     test.assert_called_once_with(
         device="qemu-arm64",
         kernel="https://example.com/vmlinux",
+        mcp_fw=None,
+        mcp_romfw=None,
         modules=None,
+        rootfs=None,
+        scp_fw=None,
+        scp_romfw=None,
+        uefi=None,
+        parameters={},
         tests=[],
         boot_args=None,
         wait_for=None,
@@ -799,7 +806,14 @@ def test_test_cli(mocker, tuxsuite_config):
     test.assert_called_once_with(
         device="qemu-arm64",
         kernel="https://example.com/vmlinux",
+        mcp_fw=None,
+        mcp_romfw=None,
         modules="https://example.com/modules.tar.xz",
+        rootfs=None,
+        scp_fw=None,
+        scp_romfw=None,
+        uefi=None,
+        parameters={},
         tests=["ltp-smoke"],
         boot_args=None,
         wait_for=None,
@@ -820,13 +834,56 @@ def test_test_cli(mocker, tuxsuite_config):
     test.assert_called_once_with(
         device="qemu-arm64",
         kernel=None,
+        mcp_fw=None,
+        mcp_romfw=None,
         modules=None,
+        rootfs=None,
+        scp_fw=None,
+        scp_romfw=None,
+        uefi=None,
+        parameters={},
         tests=["ltp-smoke"],
         boot_args=None,
         wait_for="mybuilduid",
     )
     assert wait_for_object.call_count == 1
 
+    mocker.resetall()
+    result = runner.invoke(
+        tuxsuite.cli.test,
+        [
+            "--device=fvp-morello-android",
+            "--mcp-fw=mcp_fw.bin",
+            "--mcp-romfw=mcp_romfw.bin",
+            "--rootfs=rootfs.ext4",
+            "--scp-fw=scp_fw.bin",
+            "--scp-romfw=scp_romfw.bin",
+            "--uefi=uefi.bin",
+            "--parameters=USERDATA=userdata.tar.xz",
+            "--parameters=TC_URL=toolchain.tar.xz",
+            "--tests=lldb",
+            "--",
+        ],
+    )
+    assert result.exit_code == 0
+    assert test.call_count == 1
+    test.assert_called_once_with(
+        device="fvp-morello-android",
+        kernel=None,
+        mcp_fw="mcp_fw.bin",
+        mcp_romfw="mcp_romfw.bin",
+        modules=None,
+        rootfs="rootfs.ext4",
+        scp_fw="scp_fw.bin",
+        scp_romfw="scp_romfw.bin",
+        uefi="uefi.bin",
+        parameters={"USERDATA": "userdata.tar.xz", "TC_URL": "toolchain.tar.xz"},
+        tests=["lldb"],
+        boot_args=None,
+        wait_for=None,
+    )
+    assert wait_for_object.call_count == 1
+
 
 def test_test_cli_errors(mocker):
     test = mocker.patch("tuxsuite.Test")
