@@ -6,9 +6,10 @@ import tuxsuite.cli.colors as colors
 import tuxsuite.cli.icons as icons
 from tuxsuite.cli.models import Plan
 from tuxsuite.cli.requests import get
-from tuxsuite.cli.utils import datediff
+from tuxsuite.cli.utils import LIMIT, datediff, fetch_next
 
 import json
+import sys
 
 
 def format_plan(build, tests):
@@ -197,25 +198,31 @@ def handle_get(options, config):
 
 
 def handle_list(options, config):
-    ret = get(config, f"/v1/groups/{config.group}/projects/{config.project}/plans")
+    url = f"/v1/groups/{config.group}/projects/{config.project}/plans"
+    ret = get(config, url)
     if ret.status_code != 200:
         raise NotImplementedError()
 
     plans = [Plan.new(**p) for p in ret.json()["results"][: options.limit]]
+    n_token = ret.json()["next"]
     if options.json:
         print(json.dumps([p.as_dict() for p in plans]))
     else:
-        previous_pt = None
-        for plan in plans:
-            pt = plan.provisioning_time
-            if pt is None:
-                pt = "....-..-..T..:..:........."
-            pt = pt[:-7]
+        while True:
+            previous_pt = None
+            for plan in plans:
+                pt = plan.provisioning_time
+                if pt is None:
+                    pt = "....-..-..T..:..:........."
+                pt = pt[:-7]
 
-            print(
-                f"{datediff(previous_pt, pt)} {plan.uid} {plan.name} ({plan.description})"
-            )
-            previous_pt = pt
+                print(
+                    f"{datediff(previous_pt, pt)} {plan.uid} {plan.name} ({plan.description})"
+                )
+                previous_pt = pt
+            if sys.stdout.isatty():
+                # fetch next list of plans
+                plans, n_token = fetch_next(Plan, config, url, n_token, options.limit)
     return 0
 
 
@@ -234,4 +241,4 @@ def setup_parser(parser):
     # "plan list"
     p = parser.add_parser("list")
     p.add_argument("--json", action="store_true")
-    p.add_argument("--limit", type=int, default=30)
+    p.add_argument("--limit", type=int, default=LIMIT)
